from setuptools import setup

setup(
	name		= 'menestery1',
	version		= '1.0.3',
	py_modules	= ['menestery1'],
	author		= 'hfpython',
	author_email	= 'hfpython@headfirstlabs.com',
	url		= 'http://www.headfirstlabs.com',
	description	= 'A simple printer of nested lists',
      )